@@ -9,6 +9,12 @@ fi
 fcopy -Bi /etc/apt/apt.conf.d/force_confdef
 ainsl -a  /etc/ucf.conf "^conf_force_conffold=YES"
 
+# Suppress massive warning from etckeeper / git complaining about
+# 'master' being still used as the default git branch.
+
+# Set system-wide Git options (e.g. init.defaultBranch -> main)
+fcopy -Bi /etc/gitconfig
+
 # in case the locales are already included inside the base file (Ubuntu)
 if [ -f $target/usr/sbin/locale-gen ]; then
 	exit 0
