@@ -39,18 +39,3 @@ EOF
 else
 	unset POLICYFILE
 fi
-
-# if etckeeper gets used and etckeeper uses git, then install git now
-# and pre-configure it before etckeeper installation
-install_packages -l 2>/dev/null | egrep  -q  ' etckeeper '
-with_etckeeper=$?
-install_packages -l 2>/dev/null | egrep  -q  ' git '
-with_git=$?
-if [ $with_git -eq 0 ] && [ $with_etckeeper -eq 0 ]; then
-    if [ X$verbose = X1 ]; then
-	$ROOTCMD apt-get -y install git
-    else
-	$ROOTCMD apt-get -y install git > /dev/null
-    fi
-    $ROOTCMD git config --global init.defaultBranch main
-fi
